@@ -33,6 +33,7 @@ class Auth(object):
             nis=None,
             people=None,
             slack=None,
+            slack_bot=None,
             verbose=False,
             yes=False,
     ):
@@ -50,6 +51,8 @@ class Auth(object):
             people = self.people()
         if not slack:
             slack = self.slack()
+        if not slack_bot:
+            slack_bot = self.slack_bot()
         if not verbose:
             verbose = self.verbose
         if not yes:
@@ -62,6 +65,7 @@ class Auth(object):
             nis=nis,
             people=people,
             slack=slack,
+            slack_bot=slack_bot,
             verbose=verbose,
             yes=yes
         )
@@ -858,11 +862,13 @@ class Auth(object):
         })
         return Slack(**params)
 
-    def slack_old(self):
-        """Connect to Slack API."""
-        from bitsapiclient.services.slack import Slack
+    def slack_enterprise(self, token_secret_name=None):
+        """Connect to Slack API with Enterprise Token."""
+        from bits.slack import Slack
+        if not token_secret_name:
+            token_secret_name = self.settings['slack']['enterprise_token']
         params = self.secrets.resolve({
-            'token': self.settings['slack']['token'],
+            'token': token_secret_name,
             'env': self.settings['configuration']['environment'],
             'notifications': self.settings['slack']['notifications'],
         })
